.. _community_contact:

Contact
=================

If you'd like to get in touch with the community and development of pyDataverse,
there are several options:


GitHub
------

The best way to track the development of pyDataverse is through the
`GitHub repo <https://github.com/gdcc/pyDataverse>`_.


Email
-------

The author of pyDataverse, Stefan Kasberger, can also be contacted
directly via Email.

- stefan.kasberger@univie.ac.at


Twitter
-------

pyDataverse is developed at AUSSDA - The Austrian Social Science Data Archive.
You can get regular updates of pyDataverse from our Twitter account, or get in
touch with.

- `@theaussda <https://twitter.com/theaussda>`_
